@@ -5,8 +5,8 @@
 # For license information see LICENSE.txt
 
 # Meta
-__version__ = "2.3.1"
-__version_info__ = (2, 3, 1)
+__version__ = "2.3.2"
+__version_info__ = (2, 3, 2)
 __license__ = "GPLv3"  # See LICENSE.txt
 __author__ = (
     "Dan McDougall <daniel.mcdougall@liftoffsoftware.com>,"
@@ -35,8 +35,8 @@ Performs the following:
     * Removes trailing commas.
     * Joins multiline pairs of parentheses, braces, and brackets (and removes
       extraneous whitespace within).
-    * Joins disjointed strings like, ``("some" "disjointed" "string")`` into single
-      strings: ``('''some disjointed string''')
+    * Joins disjointed strings like, ("some" "disjointed" "string") into single
+      strings: ('''some disjointed string''')
     * Preserves shebangs and encoding info (e.g. "# -- coding: utf-8 --").
     * Optionally, produces a bzip2 or gzip-compressed self-extracting python script
       containing the minified source for ultimate minification.
@@ -51,7 +51,7 @@ Performs the following:
     * Optionally, a value may be specified via --replacement-length to set the
       minimum length of random strings that are used to replace identifier names
       when obfuscating.
-    * Optionally, if using Python 3, you may specify ``--nonlatin`` to use funky
+    * Optionally, you may specify ``--nonlatin`` to use funky
       unicode characters when obfuscating. WARNING: This will result in some
       seriously hard-to-read code! **Tip:** Combine this setting with higher
       ``--replacement-length`` values to make the output even wackier.
@@ -73,10 +73,10 @@ Performs the following:
       cannot be imported into other Python scripts.
       *Added in version 2.0*
 
-Just how much space can be saved by pyminifier?  Here's a comparison:
+Just how much space can be saved by pyminifier? Here's a comparison:
 
-    * The pyminifier source (all six files) takes up about 164k.
-    * Performing basic minification on all pyminifier source files reduces that
+    * The pyminifier3 (as of version 2.1) source (all 7 files) takes up about 106k.
+    * Performing basic minification on all pyminifier3 source files reduces that
       to ~104k.
     * Minification plus obfuscation provides a further reduction to 92k.
     * Minification plus the base64-encoded gzip trick (--gzip) reduces it to 76k.
@@ -103,7 +103,7 @@ something is broken.
 .. note::
 
     The test functions below are meaningless.  They only serve as test/edge
-    cases for testing pyminifier.
+    cases for testing pyminifier3.
 """
 
 import io
@@ -221,7 +221,7 @@ def pyminify(options, files):
                   "resulting .pyz)")
             sys.exit(1)
         # Make our .pyz:
-        compression.zip_pack(files, options)
+        compression.zip_pack(files[0], options)
         return None  # Make sure we don't do anything else
     # Read in our prepend text (if any)
     prepend = None
@@ -246,8 +246,13 @@ def pyminify(options, files):
         if any(obfuscations):
             # Put together that will be used for all obfuscation functions:
             identifier_length = int(options.replacement_length)
-            name_generator = obfuscate.obfuscation_machine(
-                identifier_length=identifier_length)
+            if options.use_nonlatin:
+                name_generator = obfuscate.obfuscation_machine(
+                    use_unicode=True, identifier_length=identifier_length
+                )
+            else:
+                name_generator = obfuscate.obfuscation_machine(
+                    identifier_length=identifier_length)
             table = [{}]
         cumulative_size = 0  # For size reduction stats
         cumulative_new = 0  # Ditto
@@ -331,6 +336,7 @@ def pyminify(options, files):
                 or options.obf_import_methods:
             identifier_length = int(options.replacement_length)
             name_generator = obfuscate.obfuscation_machine(
+                use_unicode=options.use_nonlatin,
                 identifier_length=identifier_length)
             obfuscate.obfuscate(module, tokens, options)
         # Convert back to text
